Learn R Programming

tsg (version 0.1.4)

gt_apply_spanners: Apply spanner labels to a gt table based on separator-split column names

Description

Apply spanner labels to a gt table based on separator-split column names

Usage

gt_apply_spanners(gt_tbl, col_names, sep, col_labels = NULL)

Arguments