Learn R Programming

tsg (version 0.1.2)

rename_label: Rename data labels

Description

Rename data labels

Usage

rename_label(data, ...)

Value

A data frame or tibble with the specified labels renamed.

Arguments

data

A data frame or tibble to rename labels in.

...

A named list of labels to rename. The names should match the column names in the data, and the values should be the new labels.

Examples

Run this code
person_record |>
  generate_frequency(
    seeing,
    hearing,
    walking,
    remembering,
    self_caring,
    communicating
  ) |>
  collapse_list() |>
  rename_label(category = "Functional difficulty")

Run the code above in your browser using DataLab