Learn R Programming

tsg (version 0.1.2)

tsg-package: tsg: Generate Publication-Ready Statistical Tables

Description

A collection of functions for generating frequency tables and cross-tabulations of categorical variables. The resulting tables can be exported to various formats (Excel, PDF, HTML, etc.) with extensive formatting and layout customization options.

Arguments

Author

Maintainer: Bhas Abdulsamad aeabdulsamad@gmail.com (ORCID) [copyright holder]

See Also