Learn R Programming

tsg (version 0.1.2)

add_facade_alt: Add a facade to a tsg table (alternative way)

Description

This function adds a facade to a tsg, an alternative way to allow dynamic values and programmatic evaluation.

Usage

add_facade_alt(data, ...)

Value

A tsg object with the specified facade settings applied as attributes.

Arguments

data

a tsg data frame

...

List of supported facade items (see add_facade())

Examples

Run this code
person_record |>
 generate_frequency(sex) |>
 add_facade_alt(table.offsetRow = 2, table.offsetCol = 1)

Run the code above in your browser using DataLab