powered by
This function adds a facade to a tsg, an alternative way to allow dynamic values and programmatic evaluation.
tsg
add_facade_alt(data, ...)
A tsg object with the specified facade settings applied as attributes.
a tsg data frame
List of supported facade items (see add_facade())
add_facade()
person_record |> generate_frequency(sex) |> add_facade_alt(table.offsetRow = 2, table.offsetCol = 1)
Run the code above in your browser using DataLab